const router = require('express').Router();
const pug = require('pug');

const profilePug = pug.compileFile('pug/profile.pug');
const newPug = pug.compileFile('pug/profile/new.pug');

module.exports = (Sub, youtube) => router
  .get('/profile', guard, (req, res) => {
    let subs;
    req.user.getSubs()
      .then(array => {
        subs = array;
        let ids = [];
        subs.forEach(sub => ids.push(sub.channel));
        return youtube.channels.list({
          part: 'snippet',
          id: ids.join(',')
        });
      })
      .then(response => {
        const ytList = {};
        //Youtube nous donne une liste de chaînes qui n'a pas le même ordre que la liste d'id qu'on a donné, j'utilise un objet comme tableau associatif pour récupérer les ressources en fonction de l'id
        response.data.items.forEach(item => ytList[item.id] = item.snippet);
        subs.forEach(sub => {
          sub.url = 'https://www.youtube.com/channel/' + sub.channel;
          sub.img = ytList[sub.channel].thumbnails.default.url;
          sub.title = ytList[sub.channel].title;
        });
        res.send(profilePug({ user: req.user, subs: subs }));
      })
      .catch(err => {
        console.log(err);
        res.redirect('/');
      });
  })
  .get('/profile/new', guard, (req, res) => {
    res.send(newPug({ user: req.user }));
  })
  .post('/profile/new', guard, (req, res) => {
    Sub
      .create({
        UserId: req.user.id,
        keywords: req.body.q,
        channel: req.body.id
      })
      .then(res.redirect('/mysubs'));
  });

function guard(req, res, next) {
  if (req.user) {
    next();
  } else {
    res.redirect('/login');
  }
}